@@ -136,6 +136,10 @@ will add the following additional synthesized columns to the result set:
 
 =item remote_is_phone (boolean)
 
+=item remote_dns
+
+=item ifindex
+
 =back
 
 =cut
@@ -152,10 +156,13 @@ sub with_properties {
           properties.remote_is_discoverable
           properties.remote_is_wap
           properties.remote_is_phone
+          properties.remote_dns
+          properties.ifindex
         /],
         '+as' => [qw/
           error_disable_cause
-          remote_is_discoverable remote_is_wap remote_is_phone
+          remote_is_discoverable remote_is_wap remote_is_phone remote_dns
+          ifindex
         /],
         join => 'properties',
       });
